@@ -4,6 +4,7 @@ module Potoki.Produce
   transform,
   list,
   vector,
+  vectorWithIndices,
   hashMapRows,
   fileBytes,
   fileBytesAtOffset,
@@ -12,7 +13,11 @@ module Potoki.Produce
   directoryContents,
   finiteMVar,
   infiniteMVar,
+  tbmChan,
+  tmChan,
   enumInRange,
+  mergeOrdering,
+  unfoldr,
 )
 where
 
