@@ -14,14 +14,18 @@ module Potoki.Transform
   just,
   list,
   vector,
+  batch,
   distinctBy,
   distinct,
   executeIO,
   mapInIO,
+  reportProgress,
+  handleProgressAndCountOnInterval,
   -- * ByteString
   builderChunks,
   extractLines,
   extractLinesWithoutTrail,
+  extractLinesConcurrently,
   -- * State
   runState,
   execState,
@@ -34,9 +38,13 @@ module Potoki.Transform
   parseNonEmptyLineBytesConcurrently,
   -- * Concurrency
   bufferize,
+  bufferizeFlushing,
   concurrently,
+  concurrentlyInOrder,
   unsafeConcurrently,
   async,
+  concurrentlyWithBatching,
+  concurrentlyInOrderWithBatching,
   -- * File IO
   deleteFile,
   appendBytesToFile,
